"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.i18nVue = exports.trans = exports.loadLanguageAsync = void 0;
var vue_1 = require("vue");
/**
 * The Default language will be used if there is no lang provided.
 */
var DEFAULT_LANG = document.documentElement.lang || 'en';
/**
 * Stores the current options.
 */
var options = {
    lang: DEFAULT_LANG,
    resolve: function (lang) { return Promise.resolve().then(function () { return __importStar(require("../lang/".concat(lang, ".json"))); }); }
};
/**
 * Stores the loaded languages.
 */
var loaded = [];
/**
 * The active messages to use.
 */
var activeMessages = (0, vue_1.reactive)({});
/**
 * Sets the language messages to the activeMessages.
 */
function setLanguage(_a) {
    var lang = _a.lang, messages = _a.messages;
    document.querySelector('html').setAttribute('lang', lang);
    for (var _i = 0, _b = Object.entries(messages); _i < _b.length; _i++) {
        var _c = _b[_i], key = _c[0], value = _c[1];
        activeMessages[key] = value;
    }
    for (var _d = 0, _e = Object.entries(activeMessages); _d < _e.length; _d++) {
        var key = _e[_d][0];
        if (!messages[key]) {
            activeMessages[key] = null;
        }
    }
    return lang;
}
/**
 * Loads the language file.
 */
function loadLanguageAsync(lang) {
    var loadedLang = loaded.find(function (row) { return row.lang === lang; });
    if (loadedLang) {
        return Promise.resolve(setLanguage(loadedLang));
    }
    return options
        .resolve(lang)
        .then(function (_a) {
        var messages = _a.default;
        var data = { lang: lang, messages: messages };
        loaded.push(data);
        return setLanguage(data);
    })
        .catch(function (err) {
        throw new TypeError("Cannot load lang: ".concat(lang, " file: ").concat(err.message));
    });
}
exports.loadLanguageAsync = loadLanguageAsync;
/**
 * Get the translation for the given key.
 */
function trans(key, replacements) {
    if (!activeMessages[key]) {
        activeMessages[key] = key;
    }
    var message = activeMessages[key];
    var capitalize = function (s) { return s.charAt(0).toUpperCase() + s.slice(1); };
    Object.entries(replacements || []).forEach(function (_a) {
        var key = _a[0], value = _a[1];
        message = message
            .replace(":".concat(key), value)
            .replace(":".concat(key.toUpperCase()), value.toUpperCase())
            .replace(":".concat(capitalize(key)), capitalize(value));
    });
    return message;
}
exports.trans = trans;
exports.i18nVue = {
    install: function (app, currentOptions) {
        options = __assign(__assign({}, options), currentOptions);
        app.config.globalProperties.$t = function (key, replacements) { return trans(key, replacements); };
        loadLanguageAsync(options.lang);
    }
};
//# sourceMappingURL=index.js.map